@@ -157,9 +157,9 @@ checkPars <- function(x, cl) {
             stop("\n In ", cl, ": ",
                  "The first parameter of the BB8 copula has to be in the interval [1,8].",
                  call. = FALSE)
-        if (par2 <= 0 || par2 > 1)
+        if (par2 < 1e-4 || par2 > 1)
             stop("\n In ", cl, ": ",
-                 "The second parameter of the BB8 copula has to be in the interval (0,1].",
+                 "The second parameter of the BB8 copula has to be in the interval [1e-4,1].",
                  call. = FALSE)
     } else if ((family == 23 || family == 33) && (par >= 0 || par < -100)) {
         stop("\n In ", cl, ": ",
@@ -205,9 +205,9 @@ checkPars <- function(x, cl) {
             stop("\n In ", cl, ": ",
                  "The first parameter of the rotated BB8 copula has to be in the interval [-8,-1].",
                  call. = FALSE)
-        if (par2 >= 0 || par2 < -1)
+        if (par2 > -1e-4 || par2 < -1)
             stop("\n In ", cl, ": ",
-                 "The second parameter of the rotated BB8 copula has to be in the interval [-1,0).",
+                 "The second parameter of the rotated BB8 copula has to be in the interval [-1,-1e-4].",
                  call. = FALSE)
     } else if ((family == 41 || family == 51) && par <= 0) {
         stop("\n In ", cl, ": ",
