@@ -209,4 +209,86 @@ Check these declarations against the C/Fortran source code.
  {
      R_registerRoutines(dll, CEntries, NULL, NULL, NULL);
      R_useDynamicSymbols(dll, FALSE);
- }
+     R_RegisterCCallable("VineCopula", "archCDF",                           (DL_FUNC) &archCDF);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_mod",                    (DL_FUNC) &diff2hfunc_mod);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_mod_vec",                (DL_FUNC) &diff2hfunc_mod_vec);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_nu_tCopula_new",         (DL_FUNC) &diff2hfunc_nu_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_nu_tCopula_new_vec",     (DL_FUNC) &diff2hfunc_nu_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_nu_v_tCopula_new",       (DL_FUNC) &diff2hfunc_nu_v_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_nu_v_tCopula_new_vec",   (DL_FUNC) &diff2hfunc_nu_v_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_par_v_mod",              (DL_FUNC) &diff2hfunc_par_v_mod);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_par_v_mod_vec",          (DL_FUNC) &diff2hfunc_par_v_mod_vec);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_rho_nu_tCopula_new",     (DL_FUNC) &diff2hfunc_rho_nu_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_rho_nu_tCopula_new_vec", (DL_FUNC) &diff2hfunc_rho_nu_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_rho_tCopula_new",        (DL_FUNC) &diff2hfunc_rho_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_rho_v_tCopula_new",      (DL_FUNC) &diff2hfunc_rho_v_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_v_mod",                  (DL_FUNC) &diff2hfunc_v_mod);
+     R_RegisterCCallable("VineCopula", "diff2hfunc_v_mod_vec",              (DL_FUNC) &diff2hfunc_v_mod_vec);
+     R_RegisterCCallable("VineCopula", "diff2lPDF_nu_tCopula_new",          (DL_FUNC) &diff2lPDF_nu_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2lPDF_rho_nu_tCopula_new",      (DL_FUNC) &diff2lPDF_rho_nu_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2lPDF_rho_tCopula",             (DL_FUNC) &diff2lPDF_rho_tCopula);
+     R_RegisterCCallable("VineCopula", "diff2PDF_mod",                      (DL_FUNC) &diff2PDF_mod);
+     R_RegisterCCallable("VineCopula", "diff2PDF_mod_vec",                  (DL_FUNC) &diff2PDF_mod_vec);
+     R_RegisterCCallable("VineCopula", "diff2PDF_nu_tCopula_new",           (DL_FUNC) &diff2PDF_nu_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2PDF_nu_tCopula_new_vec",       (DL_FUNC) &diff2PDF_nu_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "diff2PDF_nu_u_tCopula_new",         (DL_FUNC) &diff2PDF_nu_u_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2PDF_nu_u_tCopula_new_vec",     (DL_FUNC) &diff2PDF_nu_u_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "diff2PDF_nu_v_tCopula_new",         (DL_FUNC) &diff2PDF_nu_v_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2PDF_nu_v_tCopula_new_vec",     (DL_FUNC) &diff2PDF_nu_v_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "diff2PDF_par_u_mod",                (DL_FUNC) &diff2PDF_par_u_mod);
+     R_RegisterCCallable("VineCopula", "diff2PDF_par_u_mod_vec",            (DL_FUNC) &diff2PDF_par_u_mod_vec);
+     R_RegisterCCallable("VineCopula", "diff2PDF_par_v_mod",                (DL_FUNC) &diff2PDF_par_v_mod);
+     R_RegisterCCallable("VineCopula", "diff2PDF_par_v_mod_vec",            (DL_FUNC) &diff2PDF_par_v_mod_vec);
+     R_RegisterCCallable("VineCopula", "diff2PDF_rho_nu_tCopula_new",       (DL_FUNC) &diff2PDF_rho_nu_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2PDF_rho_nu_tCopula_new_vec",   (DL_FUNC) &diff2PDF_rho_nu_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "diff2PDF_rho_tCopula",              (DL_FUNC) &diff2PDF_rho_tCopula);
+     R_RegisterCCallable("VineCopula", "diff2PDF_rho_u_tCopula_new",        (DL_FUNC) &diff2PDF_rho_u_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2PDF_rho_v_tCopula_new",        (DL_FUNC) &diff2PDF_rho_v_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diff2PDF_u_mod",                    (DL_FUNC) &diff2PDF_u_mod);
+     R_RegisterCCallable("VineCopula", "diff2PDF_u_mod_vec",                (DL_FUNC) &diff2PDF_u_mod_vec);
+     R_RegisterCCallable("VineCopula", "diff2PDF_v_mod",                    (DL_FUNC) &diff2PDF_v_mod);
+     R_RegisterCCallable("VineCopula", "diff2PDF_v_mod_vec",                (DL_FUNC) &diff2PDF_v_mod_vec);
+     R_RegisterCCallable("VineCopula", "diffhfunc_mod",                     (DL_FUNC) &diffhfunc_mod);
+     R_RegisterCCallable("VineCopula", "diffhfunc_mod_vec",                 (DL_FUNC) &diffhfunc_mod_vec);
+     R_RegisterCCallable("VineCopula", "diffhfunc_nu_tCopula_new",          (DL_FUNC) &diffhfunc_nu_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diffhfunc_nu_tCopula_new_vec",      (DL_FUNC) &diffhfunc_nu_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "diffhfunc_rho_tCopula",             (DL_FUNC) &diffhfunc_rho_tCopula);
+     R_RegisterCCallable("VineCopula", "diffhfunc_v_mod",                   (DL_FUNC) &diffhfunc_v_mod);
+     R_RegisterCCallable("VineCopula", "diffhfunc_v_mod_vec",               (DL_FUNC) &diffhfunc_v_mod_vec);
+     R_RegisterCCallable("VineCopula", "difflPDF_mod",                      (DL_FUNC) &difflPDF_mod);
+     R_RegisterCCallable("VineCopula", "difflPDF_mod_vec",                  (DL_FUNC) &difflPDF_mod_vec);
+     R_RegisterCCallable("VineCopula", "difflPDF_nu_tCopula_new",           (DL_FUNC) &difflPDF_nu_tCopula_new);
+     R_RegisterCCallable("VineCopula", "difflPDF_nu_tCopula_new_vec",       (DL_FUNC) &difflPDF_nu_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "difflPDF_rho_tCopula",              (DL_FUNC) &difflPDF_rho_tCopula);
+     R_RegisterCCallable("VineCopula", "diffPDF_mod",                       (DL_FUNC) &diffPDF_mod);
+     R_RegisterCCallable("VineCopula", "diffPDF_mod_vec",                   (DL_FUNC) &diffPDF_mod_vec);
+     R_RegisterCCallable("VineCopula", "diffPDF_nu_tCopula_new",            (DL_FUNC) &diffPDF_nu_tCopula_new);
+     R_RegisterCCallable("VineCopula", "diffPDF_nu_tCopula_new_vec",        (DL_FUNC) &diffPDF_nu_tCopula_new_vec);
+     R_RegisterCCallable("VineCopula", "diffPDF_rho_tCopula",               (DL_FUNC) &diffPDF_rho_tCopula);
+     R_RegisterCCallable("VineCopula", "diffPDF_u_mod",                     (DL_FUNC) &diffPDF_u_mod);
+     R_RegisterCCallable("VineCopula", "diffPDF_u_mod_vec",                 (DL_FUNC) &diffPDF_u_mod_vec);
+     R_RegisterCCallable("VineCopula", "diffPDF_v_mod",                     (DL_FUNC) &diffPDF_v_mod);
+     R_RegisterCCallable("VineCopula", "diffPDF_v_mod_vec",                 (DL_FUNC) &diffPDF_v_mod_vec);
+     R_RegisterCCallable("VineCopula", "Hfunc1",                            (DL_FUNC) &Hfunc1);
+     R_RegisterCCallable("VineCopula", "Hfunc1_vec",                        (DL_FUNC) &Hfunc1_vec);
+     R_RegisterCCallable("VineCopula", "Hfunc2",                            (DL_FUNC) &Hfunc2);
+     R_RegisterCCallable("VineCopula", "Hfunc2_vec",                        (DL_FUNC) &Hfunc2_vec);
+     R_RegisterCCallable("VineCopula", "Hinv1",                             (DL_FUNC) &Hinv1);
+     R_RegisterCCallable("VineCopula", "Hinv1_vec",                         (DL_FUNC) &Hinv1_vec);
+     R_RegisterCCallable("VineCopula", "Hinv2",                             (DL_FUNC) &Hinv2);
+     R_RegisterCCallable("VineCopula", "Hinv2_vec",                         (DL_FUNC) &Hinv2_vec);
+     R_RegisterCCallable("VineCopula", "ktau",                              (DL_FUNC) &ktau);
+     R_RegisterCCallable("VineCopula", "ktau_matrix",                       (DL_FUNC) &ktau_matrix);
+     R_RegisterCCallable("VineCopula", "LL_mod2",                           (DL_FUNC) &LL_mod2);
+     R_RegisterCCallable("VineCopula", "LL_mod_seperate",                   (DL_FUNC) &LL_mod_seperate);
+     R_RegisterCCallable("VineCopula", "pcc",                               (DL_FUNC) &pcc);
+     R_RegisterCCallable("VineCopula", "PDF_seperate",                      (DL_FUNC) &PDF_seperate);
+     R_RegisterCCallable("VineCopula", "PDF_seperate_vec",                  (DL_FUNC) &PDF_seperate_vec);
+     R_RegisterCCallable("VineCopula", "RvinePIT",                          (DL_FUNC) &RvinePIT);
+     R_RegisterCCallable("VineCopula", "SimulateRVine",                     (DL_FUNC) &SimulateRVine);
+     R_RegisterCCallable("VineCopula", "Tawn2",                             (DL_FUNC) &Tawn2);
+     R_RegisterCCallable("VineCopula", "TawnC",                             (DL_FUNC) &TawnC);
+     R_RegisterCCallable("VineCopula", "VineLogLikRvine",                   (DL_FUNC) &VineLogLikRvine);
+     R_RegisterCCallable("VineCopula", "VineLogLikRvine2",                  (DL_FUNC) &VineLogLikRvine2);
+     R_RegisterCCallable("VineCopula", "VineLogLikRvineGradient",           (DL_FUNC) &VineLogLikRvineGradient);
+}
