@@ -1,13 +1,13 @@
-#include "vine.h"
-#include "memoryhandling.h"
-#include "likelihood.h"
-#include "deriv.h"
-#include "deriv2.h"
-#include "tcopuladeriv.h"
-#include "tcopuladeriv_new.h"
-#include "rvine.h"
-#include "rvinederiv.h"
-#include "rvinederiv2.h"
+#include "VineCopula/vine.h"
+#include "VineCopula/memoryhandling.h"
+#include "VineCopula/likelihood.h"
+#include "VineCopula/deriv.h"
+#include "VineCopula/deriv2.h"
+#include "VineCopula/tcopuladeriv.h"
+#include "VineCopula/tcopuladeriv_new.h"
+#include "VineCopula/rvine.h"
+#include "VineCopula/rvinederiv.h"
+#include "VineCopula/rvinederiv2.h"
 
 
 #define UMAX  1-1e-10
